@@ -1,11 +1,11 @@
 ;;; gnuserv.el --- Lisp interface code between Emacs and gnuserv
 ;; Copyright (C) 1989-1997 Free Software Foundation, Inc.
 
-;; Version: 3.12
+;; Version: 3.11
 ;; Author: Andy Norman (ange@hplb.hpl.hp.com), originally based on server.el
-;;         Hrvoje Niksic <hniksic@xemacs.org>
+;;         Hrvoje Niksic <hniksic@srce.hr>
 ;; Maintainer: Jan Vroonhof <vroonhof@math.ethz.ch>,
-;;             Hrvoje Niksic <hniksic@xemacs.org>
+;;             Hrvoje Niksic <hniksic@srce.hr>
 ;; Keywords: environment, processes, terminals
 
 ;; This file is part of XEmacs.
@@ -73,7 +73,7 @@
 ;; Jan Vroonhof
 ;;     Customized.
 ;;
-;; Hrvoje Niksic <hniksic@xemacs.org> May/1997
+;; Hrvoje Niksic <hniksic@srce.hr> May/1997
 ;;     Completely rewritten.  Now uses `defstruct' and other CL stuff
 ;;     to define clients cleanly.  Many thanks to Dave Gillespie!
 ;;
@@ -271,7 +271,6 @@ Each element is a gnuclient structure that identifies a client.")
 (defun gnuserv-main-frame-function (type)
   "Return a sensible value for the main Emacs frame."
   (if (or (eq type 'x)
-	  (eq type 'gtk)
 	  (eq type 'mswindows))
       (car (frame-list))
     nil))
@@ -281,7 +280,6 @@ Each element is a gnuclient structure that identifies a client.")
 This is meant in the X sense, so it will not return frames that are on another
 visual screen.  Totally visible frames are preferred.  If none found, return nil."
   (if (or (eq type 'x)
-	  (eq type 'gtk)
 	  (eq type 'mswindows))
       (cond ((car (filtered-frame-list 'frame-totally-visible-p
 				       (selected-device))))
@@ -339,8 +337,8 @@ visual screen.  Totally visible frames are preferred.  If none found, return nil
   "Process gnuserv client requests to execute Emacs commands."
   (setq gnuserv-string (concat gnuserv-string string))
   ;; C-d means end of request.
-  (when (string-match "\C-d\n?\\'" gnuserv-string)
-    (cond ((string-match "\\`[0-9]+" gnuserv-string) ; client request id
+  (when (string-match "\C-d\\'" gnuserv-string)
+    (cond ((string-match "^[0-9]+" gnuserv-string) ; client request id
 	   (let ((header (read-from-string gnuserv-string)))
 	     ;; Set the client we are talking to.
 	     (setq gnuserv-current-client (car header))
@@ -361,9 +359,8 @@ visual screen.  Totally visible frames are preferred.  If none found, return nil
 		     (signal 'quit nil)))
 	     (setq gnuserv-string "")))
 	  (t
-	   (let ((response (car (split-string gnuserv-string "\C-d"))))
-	     (setq gnuserv-string "")
-	     (error "%s: invalid response from gnuserv" response))))))
+	   (error "%s: invalid response from gnuserv" gnuserv-string)
+	   (setq gnuserv-string "")))))
 
 ;; This function is somewhat of a misnomer.  Actually, we write to the
 ;; server (using `process-send-string' to gnuserv-process), which
@@ -430,7 +427,6 @@ If a flag is `view', view the files read-only."
 			 ((null dest-frame)
 			  (case (car type)
 			    (tty (apply 'make-tty-device (cdr type)))
-			    (gtk (make-gtk-device))
 			    (x   (make-x-device (cadr type)))
 			    (mswindows   (make-mswindows-device))
 			    (t   (error "Invalid device type"))))
@@ -446,7 +442,6 @@ If a flag is `view', view the files read-only."
 	   (client (make-gnuclient :id gnuserv-current-client
 				   :device device
 				   :frame new-frame)))
-      (select-frame frame)
       (setq gnuserv-current-client nil)
       ;; If the device was created by this client, push it to the list.
       (and (/= old-device-num (length (device-list)))
