@@ -58,9 +58,9 @@
 ;; Massive changes by Christoph Wedler <wedler@fmi.uni-passau.de>
 ;; Some changes for XEmacs 20.3 by hniksic
 
-;; #### The maintainer is supposed to be stig, but I haven't seen him
+;; ### The maintainer is supposed to be stig, but I haven't seen him
 ;; around for ages.  The real maintainer for the moment is Hrvoje
-;; Niksic <hniksic@xemacs.org>.
+;; Niksic <hniksic@srce.hr>.
 
 ;;; Code:
 
@@ -211,7 +211,7 @@ This map inherits from `hyper-apropos-help-map.'")
 
 (defvar hyper-apropos-mode-hook nil
   "*User function run after hyper-apropos mode initialization.  Usage:
-\(add-hook 'hyper-apropos-mode-hook #'(lambda () ... your init forms ...)).")
+\(setq hyper-apropos-mode-hook '(lambda () ... your init forms ...)).")
 
 ;; ---------------------------------------------------------------------- ;;
 
@@ -243,22 +243,16 @@ See also `hyper-apropos-mode'."
       (setq hyper-apropos-prev-wconfig (current-window-configuration)))
   (if (string= "" regexp)
       (if (get-buffer hyper-apropos-apropos-buf)
-	  (progn
-	    (setq regexp hyper-apropos-last-regexp)
-	    (if toggle-apropos
-		(hyper-apropos-toggle-programming-flag)
-	      (message "Using last search results")))
+	  (if toggle-apropos
+	      (hyper-apropos-toggle-programming-flag)
+	    (message "Using last search results"))
 	(error "Be more specific..."))
     (set-buffer (get-buffer-create hyper-apropos-apropos-buf))
     (setq buffer-read-only nil)
     (erase-buffer)
     (if toggle-apropos
-	(if (local-variable-p 'hyper-apropos-programming-apropos
-			      (current-buffer))
-	    (setq hyper-apropos-programming-apropos
-		  (not hyper-apropos-programming-apropos))
-	  (set (make-local-variable 'hyper-apropos-programming-apropos)
-	       (not (default-value 'hyper-apropos-programming-apropos)))))
+	(set (make-local-variable 'hyper-apropos-programming-apropos)
+	     (not (default-value 'hyper-apropos-programming-apropos))))
     (let ((flist (apropos-internal regexp
 				   (if hyper-apropos-programming-apropos
 				       #'fboundp
@@ -386,7 +380,7 @@ General Commands:
 
 ;; ---------------------------------------------------------------------- ;;
 
-;; similar to `describe-key-briefly', copied from help.el by CW
+;; similar to `describe-key-briefly', copied from prim/help.el by CW
 
 ;;;###autoload
 (defun hyper-describe-key (key)
@@ -438,9 +432,7 @@ General Commands:
 	(if (and (or (symbolp defn) (symbolp (setq defn (car-safe defn))))
 		 defn
 		 show)
-	    (hyper-apropos-get-doc defn t))
-	(or (memq major-mode '(hyper-apropos-mode hyper-apropos-help-mode))
-	  (setq hyper-apropos-prev-wconfig (current-window-configuration)))))))
+	    (hyper-apropos-get-doc defn t))))))
 
 ;;;###autoload
 (defun hyper-describe-face (symbol &optional this-ref-buffer)
@@ -460,11 +452,12 @@ See also `hyper-apropos' and `hyper-describe-function'."
 			  (if v
 			      (format " (default %s): " v)
 			    ": "))
-		  (mapcar #'(lambda (x) (list (symbol-name x)))
+		  (mapcar (function (lambda (x) (list (symbol-name x))))
 			  (face-list))
-		  nil t nil 'hyper-apropos-face-history
-		  (and v (symbol-name v)))))
-     (list (intern-soft val)
+		  nil t nil 'hyper-apropos-face-history)))
+     (list (if (string= val "")
+	       (progn (push (symbol-name v) hyper-apropos-face-history) v)
+	     (intern-soft val))
 	   current-prefix-arg)))
   (if (null symbol)
       (message "Sorry, nothing to describe.")
@@ -531,10 +524,10 @@ See also `hyper-apropos' and `hyper-describe-function'."
 			 (if v
 			     (format " (default %s): " v)
 			   ": "))
-		 obarray predicate t nil 'variable-history
-		 (and v (symbol-name v)))))
-    (intern-soft val)))
-
+		 obarray predicate t nil 'variable-history)))
+    (if (string= val "")
+	(progn (push (symbol-name v) variable-history) v)
+      (intern-soft val))))
 ;;;###autoload
 (define-obsolete-function-alias
   'hypropos-read-variable-symbol 'hyper-apropos-read-variable-symbol)
@@ -550,9 +543,10 @@ See also `hyper-apropos' and `hyper-describe-function'."
 				     (format "%s (default %s): " prompt fn)
 				   (format "%s: " prompt))
 				 obarray 'fboundp t nil
-				 'function-history
-				 (and fn (symbol-name fn)))))
-    (intern-soft val)))
+				 'function-history)))
+    (if (equal val "")
+	(progn (push (symbol-name fn) function-history) fn)
+      (intern-soft val))))
 
 (defun hyper-apropos-last-help (arg)
   "Go back to the last symbol documented in the *Hyper Help* buffer."
@@ -892,13 +886,14 @@ See also `hyper-apropos' and `hyper-describe-function'."
 	     (progn
 	       (setq ok t)
 	       (copy-face symbol 'hyper-apropos-temp-face 'global)
-	       (mapcar #'(lambda (property)
-			   (setq symtype (face-property-instance symbol
-								 property))
-			   (if symtype
-			       (set-face-property 'hyper-apropos-temp-face
-						  property
-						  symtype)))
+	       (mapcar (function
+			(lambda (property)
+			  (setq symtype (face-property-instance symbol
+								property))
+			  (if symtype
+			      (set-face-property 'hyper-apropos-temp-face
+						 property
+						 symtype))))
 		       built-in-face-specifiers)
 	       (setq font (cons (face-property-instance symbol 'font nil 0 t)
 				(face-property-instance symbol 'font))
